@@ -14,7 +14,7 @@ from .Helpers.resourceAPI import ResourceAPI
 async def run():
 
     formats = ('packwiz', 'Modrinth', 'CurseForge', 'Intermediate')
-    providers = ('Github', 'CurseForge', 'Modrinth')
+    providers = ('GitHub', 'CurseForge', 'Modrinth')
 
     modrinth_search_help = """How accurate modrith search will be:\n
                               exact - uses hash to find file (default)\n
@@ -26,7 +26,6 @@ async def run():
     arg_parser.add_argument('-i', '--input', dest='input', type=Path, help='Path to pack', required=True)
     arg_parser.add_argument('-f', '--format', dest='formats', type=str, nargs="+", choices=formats, help='Format to convert to', required=True)
     arg_parser.add_argument('-o', '--output', dest='output', type=Path, help='Specify output directory (optional)', default=Path.cwd())
-    arg_parser.add_argument('--github-auth', dest='github_auth', type=str, help='Github Auth in format username:token')
     arg_parser.add_argument('--modrinth-search', dest='modrinth_search', type=str, choices=('exact', 'accurate', 'loose'), help=modrinth_search_help, default='exact')
     arg_parser.add_argument('--exclude-providers', dest='excluded_providers', type=str, nargs="+", choices=providers, help='List of providers you which to exclude from search', default=str())
     arg_parser.add_argument('--exclude-forbidden', dest='ignore_CF_flag', action='store_false', help='Exclude mods which not allowed for distribution from CurseForge search (disabled by default)')
@@ -38,13 +37,8 @@ async def run():
     ResourceAPI.excluded_providers = args.excluded_providers
     ResourceAPI.ignore_CF_flag = args.ignore_CF_flag
 
-    if args.github_auth:
-        login, password = args.github_auth.split(":")
-        auth = BasicAuth(login, password, "utf-8")
-    else: auth = None
-
     cache = FileBackend("mmc-export", use_temp=True, allowed_methods=("GET", "POST", "HEAD"))
-    async with CachedSession(cache=cache, connector=TCPConnector(limit=0), auth=auth) as session:
+    async with CachedSession(cache=cache, connector=TCPConnector(limit=0)) as session:
 
         parser = Parser(args.input, session)
         intermediate = await parser.parse()
